/******************************************************************************
 * RatingGraphPanelConfigure.java - 
 * $Id: RatingGraphPanelConfigureDialog.java,v 1.3 2010/03/03 13:12:21 inim Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright© 2009,2010 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: RatingGraphPanelConfigureDialog.java,v $
 * Revision 1.3  2010/03/03 13:12:21  inim
 * Replaced (c) sign in comment mangled by CVS default encoding back to UTF-8
 *
 * Revision 1.2  2010/03/03 12:19:49  inim
 * Moved source to UTF8 encoding from CP1252 encoding. To this end all source files' (c) message was updated to "Copyright© 2009,2010 - Dick Balaska - BuckoSoft, Corp.". This replaces the (c) sign to UTF8, and adds the new year 2010.
 *
 * Revision 1.1  2010/02/04 05:57:53  inim
 * Mavenized project folder layout
 *
 * Revision 1.2  2010/01/29 23:38:35  dick
 * Javadoc.
 *
 * Revision 1.1  2010/01/29 23:07:35  dick
 * RatingGraphPanelConfigure becomes RatingGraphPanelConfigureDialog.
 *
 * Revision 1.1  2010/01/27 02:11:10  dick
 * Empty RatingGraphPanelConfigure.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import com.buckosoft.fibs.BuckoFIBS.BFProperties;
import com.buckosoft.fibs.BuckoFIBS.CommandDispatcher;
import com.buckosoft.fibs.domain.config.RatingGraphConfig;

/**
 * @author dick
 * @since Jan 26, 2010
 * @see 
 */
public class RatingGraphPanelConfigureDialog extends JDialog implements DocumentListener {
	private	final static boolean DEBUG = false;
	private	CommandDispatcher	commandDispatcher;
	private	BFProperties		properties;

	private static final long serialVersionUID = 1L;
	private JPanel jContentPane = null;
	private JPanel jPanelGraphType = null;
	private JRadioButton jRadioButtonAllMatches = null;
	private JRadioButton jRadioButtonLastXMatches = null;
	private JTextField jTextFieldNumberOfMatches = null;
	private JRadioButton jRadioButtonFromDate = null;
	private JPanel jPanelOKCancel = null;
	private JButton jButtonOK = null;
	private JButton jButtonCancel = null;
	private	RatingGraphConfig ratingGraphConfig;
	
	/**
	 * @param owner
	 */
	public RatingGraphPanelConfigureDialog(Frame owner) {
		super(owner);
		initialize();
	}

	/** Create and display the RatingGraphConfigure dialog.
	 * Just set and forget.  It's modal and manages ok and cancel on its own.
	 * @param owner Probably an instance of MainDialog
	 * @param commandDispatcher The BuckoFIBS commandDispatcher
	 */
	public RatingGraphPanelConfigureDialog(JFrame owner, CommandDispatcher commandDispatcher) {
		super(owner, true);
		this.commandDispatcher = commandDispatcher;
		this.properties = commandDispatcher.getProperties();
		initialize();
		this.setLocationRelativeTo(owner);

		BFProperties props = this.commandDispatcher.getProperties();
		ratingGraphConfig = props.getRatingGraphConfig().clone();
		switch (ratingGraphConfig.getTypeAsInt()) {
		case 0:
			this.jRadioButtonAllMatches.getModel().setSelected(true);
			break;
		case 1:
			this.jRadioButtonLastXMatches.getModel().setSelected(true);
			break;
		case 2:
			this.jRadioButtonFromDate.getModel().setSelected(true);
			break;
		}
		this.jTextFieldNumberOfMatches.setText("" + props.getRatingGraphConfig().getMatchCount());
		this.jTextFieldNumberOfMatches.setEnabled(ratingGraphConfig.getType() == RatingGraphConfig.Type.displayLastXMatches);
	}

	/** This method initializes this
	 * @return void
	 */
	private void initialize() {
		this.setSize(300, 200);
		this.setTitle("Configure the Rating Graph");
		this.setContentPane(getJContentPane());
	}

	private void okButtonActionPerformed(java.awt.event.ActionEvent evt) {
		setVisible(false);
		RatingGraphConfig rgc = this.commandDispatcher.getProperties().getRatingGraphConfig();
		if (this.jRadioButtonAllMatches.getModel().isSelected())
			rgc.setTypeAsInt(0);
		if (this.jRadioButtonLastXMatches.getModel().isSelected())
			rgc.setTypeAsInt(1);
		if (this.jRadioButtonFromDate.getModel().isSelected())
			rgc.setTypeAsInt(2);

		int i = -1;
		try {
			i = Integer.parseInt(this.jTextFieldNumberOfMatches.getText());
		} catch (NumberFormatException e) {
			i = -1;
		}
		if (i < 1)
			i = 1;
		rgc.setMatchCount(i);
		this.properties.setRatingGraphConfig(rgc);
		dispose();
	}

	private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {
		setVisible(false);
		dispose();
	}

	/** This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			BorderLayout borderLayout = new BorderLayout();
			borderLayout.setHgap(15);
			borderLayout.setVgap(11);
			jContentPane = new JPanel();
			jContentPane.setLayout(borderLayout);
			jContentPane.add(getJPanelGraphType(), BorderLayout.CENTER);
			jContentPane.add(getJPanelOKCancel(), BorderLayout.SOUTH);
		}
		return jContentPane;
	}

	/** This method initializes jPanelGraphType	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanelGraphType() {
		if (jPanelGraphType == null) {
			GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
			gridBagConstraints4.gridx = 0;
			gridBagConstraints4.gridy = 4;
			GridBagConstraints gridBagConstraints3 = new GridBagConstraints();
			gridBagConstraints3.gridx = 0;
			gridBagConstraints3.anchor = GridBagConstraints.WEST;
			gridBagConstraints3.gridy = 3;
			GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
			gridBagConstraints2.fill = GridBagConstraints.VERTICAL;
			gridBagConstraints2.gridy = 2;
			gridBagConstraints2.weightx = 1.0;
			gridBagConstraints2.anchor = GridBagConstraints.WEST;
			gridBagConstraints2.ipadx = 0;
			gridBagConstraints2.insets = new Insets(0, 22, 0, 0);
			gridBagConstraints2.gridx = 0;
			GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
			gridBagConstraints1.gridx = 0;
			gridBagConstraints1.anchor = GridBagConstraints.WEST;
			gridBagConstraints1.gridy = 1;
			GridBagConstraints gridBagConstraints = new GridBagConstraints();
			gridBagConstraints.gridx = 0;
			gridBagConstraints.anchor = GridBagConstraints.WEST;
			gridBagConstraints.gridy = 0;
			jPanelGraphType = new JPanel();
			jPanelGraphType.setLayout(new GridBagLayout());
			jPanelGraphType.add(getJRadioButtonAllMatches(), gridBagConstraints);
			jPanelGraphType.add(getJRadioButtonLastXMatches(), gridBagConstraints1);
			jPanelGraphType.add(getJTextFieldNumberOfMatches(), gridBagConstraints2);
			jPanelGraphType.add(getJRadioButtonFromDate(), gridBagConstraints3);
			ButtonGroup group = new ButtonGroup();
		    group.add(getJRadioButtonAllMatches());
		    group.add(getJRadioButtonLastXMatches());
		    group.add(getJRadioButtonFromDate());
		}
		return jPanelGraphType;
	}

	/** This method initializes jRadioButtonAllMatches	
	 * 	
	 * @return javax.swing.JRadioButton	
	 */
	private JRadioButton getJRadioButtonAllMatches() {
		if (jRadioButtonAllMatches == null) {
			jRadioButtonAllMatches = new JRadioButton();
			jRadioButtonAllMatches.setText("All Matches");
			jRadioButtonAllMatches.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					ratingGraphConfig.setType(RatingGraphConfig.Type.displayAllMatches);
					commandDispatcher.dispatch(CommandDispatcher.Command.SET_RATING_GRAPH_CONFIG, ratingGraphConfig);
				}
			});
		}
		return jRadioButtonAllMatches;
	}

	/** This method initializes jRadioButtonLastXMatches	
	 * 	
	 * @return javax.swing.JRadioButton	
	 */
	private JRadioButton getJRadioButtonLastXMatches() {
		if (jRadioButtonLastXMatches == null) {
			jRadioButtonLastXMatches = new JRadioButton();
			jRadioButtonLastXMatches.setText("Last X Matches");
			jRadioButtonLastXMatches.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					ratingGraphConfig.setType(RatingGraphConfig.Type.displayLastXMatches);
					commandDispatcher.dispatch(CommandDispatcher.Command.SET_RATING_GRAPH_CONFIG, ratingGraphConfig);
				}
			});
			jRadioButtonLastXMatches
					.addChangeListener(new javax.swing.event.ChangeListener() {
						public void stateChanged(javax.swing.event.ChangeEvent e) {
							getJTextFieldNumberOfMatches().setEnabled(jRadioButtonLastXMatches.getModel().isSelected());
						}
					});
		}
		return jRadioButtonLastXMatches;
	}

	/** This method initializes jTextFieldNumberOfMatches	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getJTextFieldNumberOfMatches() {
		if (jTextFieldNumberOfMatches == null) {
			jTextFieldNumberOfMatches = new JTextField();
			jTextFieldNumberOfMatches.setPreferredSize(new Dimension(60, 20));
			jTextFieldNumberOfMatches.addKeyListener(new java.awt.event.KeyAdapter() {
				public void keyTyped(java.awt.event.KeyEvent e) {
					
				}
			});
			jTextFieldNumberOfMatches.getDocument().addDocumentListener(this);
		}
		return jTextFieldNumberOfMatches;
	}

	/* (non-Javadoc)
	 * @see javax.swing.event.DocumentListener#changedUpdate(javax.swing.event.DocumentEvent)
	 */
	@Override
	public void changedUpdate(DocumentEvent arg0) {
		updateFromTextChanged(arg0);
		
	}

	/* (non-Javadoc)
	 * @see javax.swing.event.DocumentListener#insertUpdate(javax.swing.event.DocumentEvent)
	 */
	@Override
	public void insertUpdate(DocumentEvent arg0) {
		updateFromTextChanged(arg0);
	}

	/* (non-Javadoc)
	 * @see javax.swing.event.DocumentListener#removeUpdate(javax.swing.event.DocumentEvent)
	 */
	@Override
	public void removeUpdate(DocumentEvent arg0) {
		updateFromTextChanged(arg0);
	}

	private void updateFromTextChanged(DocumentEvent documentEvent) {
		int i = -1;
		try {
			i = Integer.parseInt(jTextFieldNumberOfMatches.getText());
		} catch (NumberFormatException e1) {
			i = -1;
		}
		if (i < 1)
			i = 1;
		if (DEBUG)
			System.out.println("docChanged(" + i + ")");
		ratingGraphConfig.setMatchCount(i);
		commandDispatcher.dispatch(CommandDispatcher.Command.SET_RATING_GRAPH_CONFIG, ratingGraphConfig);

	}

	/**
	 * This method initializes jRadioButtonFromDate	
	 * 	
	 * @return javax.swing.JRadioButton	
	 */
	private JRadioButton getJRadioButtonFromDate() {
		if (jRadioButtonFromDate == null) {
			jRadioButtonFromDate = new JRadioButton();
			jRadioButtonFromDate.setText("From Date");
			jRadioButtonFromDate.setEnabled(false);
			jRadioButtonFromDate.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					System.out.println("actionPerformed()"); // TODO Auto-generated Event stub actionPerformed()
				}
			});
		}
		return jRadioButtonFromDate;
	}

	/**
	 * This method initializes jPanelOKCancel	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanelOKCancel() {
		if (jPanelOKCancel == null) {
			GridBagConstraints gridBagConstraints6 = new GridBagConstraints();
			gridBagConstraints6.gridx = 1;
			gridBagConstraints6.anchor = GridBagConstraints.EAST;
			gridBagConstraints6.insets = new Insets(0, 30, 0, 0);
			gridBagConstraints6.gridy = 5;
			GridBagConstraints gridBagConstraints5 = new GridBagConstraints();
			gridBagConstraints5.gridx = 0;
			gridBagConstraints5.weighty = 0.5;
			gridBagConstraints5.fill = GridBagConstraints.BOTH;
			gridBagConstraints5.anchor = GridBagConstraints.CENTER;
			gridBagConstraints5.insets = new Insets(0, 0, 0, 20);
			gridBagConstraints5.weightx = 0.0;
			gridBagConstraints5.gridy = 5;
			jPanelOKCancel = new JPanel();
			jPanelOKCancel.setLayout(new GridBagLayout());
			jPanelOKCancel.add(getJButtonOK(), gridBagConstraints5);
			jPanelOKCancel.add(getJButtonCancel(), gridBagConstraints6);
		}
		return jPanelOKCancel;
	}

	/**
	 * This method initializes jButtonOK	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonOK() {
		if (jButtonOK == null) {
			jButtonOK = new JButton();
			jButtonOK.setText("OK");
			jButtonOK.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					okButtonActionPerformed(e);
				}
			});
		}
		return jButtonOK;
	}

	/**
	 * This method initializes jButtonCancel	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonCancel() {
		if (jButtonCancel == null) {
			jButtonCancel = new JButton();
			jButtonCancel.setText("Cancel");
			jButtonCancel.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					cancelButtonActionPerformed(e);
				}
			});
		}
		return jButtonCancel;
	}

}  //  @jve:decl-index=0:visual-constraint="13,8"
